@@ -25,23 +25,38 @@ import java.util.Properties;
 import java.util.concurrent.Callable;
 import org.apache.baremaps.cli.Baremaps.VersionProvider;
 import org.apache.baremaps.cli.database.Database;
+import org.apache.baremaps.cli.dem.DEM;
 import org.apache.baremaps.cli.geocoder.Geocoder;
 import org.apache.baremaps.cli.iploc.IpLoc;
 import org.apache.baremaps.cli.map.Map;
 import org.apache.baremaps.cli.workflow.Workflow;
 import org.apache.logging.log4j.Level;
 import org.apache.logging.log4j.core.config.Configurator;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 import picocli.CommandLine;
 import picocli.CommandLine.Command;
 import picocli.CommandLine.IVersionProvider;
 import picocli.CommandLine.Option;
 
-@Command(name = "baremaps", description = "A toolkit for producing vector tiles.",
-    versionProvider = VersionProvider.class, subcommands = {Workflow.class, Database.class,
-        Map.class, Geocoder.class, IpLoc.class},
+@Command(
+    name = "baremaps",
+    description = "A toolkit for producing vector tiles.",
+    versionProvider = VersionProvider.class,
+    subcommands = {
+        Workflow.class,
+        Database.class,
+        Map.class,
+        Geocoder.class,
+        IpLoc.class,
+        DEM.class
+    },
     sortOptions = false)
+@SuppressWarnings("squid:S106")
 public class Baremaps implements Callable<Integer> {
 
+  private static final Logger logger = LoggerFactory.getLogger(Baremaps.class);
+
   @Option(names = {"-V", "--version"}, versionHelp = true, description = "Print version info.")
   boolean version;
 
@@ -61,9 +76,12 @@ public class Baremaps implements Callable<Integer> {
     }
 
     // Execute the command
-    CommandLine cmd = new CommandLine(new Baremaps()).setUsageHelpLongOptionsMaxWidth(30)
+    CommandLine commandLine = new CommandLine(new Baremaps())
+        .setCaseInsensitiveEnumValuesAllowed(true)
+        .setUsageHelpLongOptionsMaxWidth(30)
         .addMixin("options", new Options());
-    cmd.execute(args);
+
+    commandLine.execute(args);
   }
 
   @Override
