@@ -33,13 +33,16 @@ import java.util.concurrent.Callable;
 import org.apache.baremaps.server.GeocoderResource;
 import org.apache.lucene.search.SearcherFactory;
 import org.apache.lucene.search.SearcherManager;
-import org.apache.lucene.store.MMapDirectory;
+import org.apache.lucene.store.FSDirectory;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import picocli.CommandLine.Command;
 import picocli.CommandLine.Option;
 
-@Command(name = "serve", description = "Start a tile server with caching capabilities.")
+@Command(
+    name = "serve",
+    description = "Start a tile server with caching capabilities.")
+@SuppressWarnings("squid:S106")
 public class Serve implements Callable<Integer> {
 
   private static final Logger logger = LoggerFactory.getLogger(Serve.class);
@@ -59,7 +62,7 @@ public class Serve implements Callable<Integer> {
   public Integer call() throws Exception {
 
     try (
-        var directory = MMapDirectory.open(indexDirectory);
+        var directory = FSDirectory.open(indexDirectory);
         var searcherManager = new SearcherManager(directory, new SearcherFactory())) {
 
       var serverBuilder = Server.builder();
