@@ -27,27 +27,32 @@ import com.linecorp.armeria.server.docs.DocService;
 import com.linecorp.armeria.server.file.FileService;
 import com.linecorp.armeria.server.file.HttpFile;
 import java.io.IOException;
+import java.nio.ByteBuffer;
 import java.nio.file.Path;
 import java.util.concurrent.Callable;
 import java.util.function.Supplier;
+import org.apache.baremaps.cli.BaremapsException;
 import org.apache.baremaps.cli.Options;
 import org.apache.baremaps.config.ConfigReader;
+import org.apache.baremaps.maplibre.style.Style;
+import org.apache.baremaps.maplibre.tileset.Tileset;
+import org.apache.baremaps.postgres.utils.PostgresUtils;
 import org.apache.baremaps.server.ChangeResource;
 import org.apache.baremaps.server.StyleResource;
-import org.apache.baremaps.server.TileResource;
 import org.apache.baremaps.server.TilesetResource;
+import org.apache.baremaps.server.VectorTileResource;
 import org.apache.baremaps.tilestore.TileStore;
 import org.apache.baremaps.tilestore.postgres.PostgresTileStore;
-import org.apache.baremaps.utils.PostgresUtils;
-import org.apache.baremaps.vectortile.style.Style;
-import org.apache.baremaps.vectortile.tileset.Tileset;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import picocli.CommandLine.Command;
 import picocli.CommandLine.Mixin;
 import picocli.CommandLine.Option;
 
-@Command(name = "dev", description = "Start a development server with live reload.")
+@Command(
+    name = "dev",
+    description = "Start a development server with live reload.")
+@SuppressWarnings("squid:S106")
 public class Dev implements Callable<Integer> {
 
   private static final Logger logger = LoggerFactory.getLogger(Dev.class);
@@ -88,11 +93,11 @@ public class Dev implements Callable<Integer> {
         var config = configReader.read(tilesetPath);
         return objectMapper.readValue(config, Tileset.class);
       } catch (IOException e) {
-        throw new RuntimeException(e);
+        throw new BaremapsException(e);
       }
     };
 
-    var tileStoreSupplier = (Supplier<TileStore>) () -> {
+    var tileStoreSupplier = (Supplier<TileStore<ByteBuffer>>) () -> {
       var tileJSON = tilesetSupplier.get();
       return new PostgresTileStore(datasource, tileJSON);
     };
@@ -102,7 +107,7 @@ public class Dev implements Callable<Integer> {
         var config = configReader.read(stylePath);
         return objectMapper.readValue(config, Style.class);
       } catch (IOException e) {
-        throw new RuntimeException(e);
+        throw new BaremapsException(e);
       }
     };
 
@@ -112,7 +117,8 @@ public class Dev implements Callable<Integer> {
     var jsonResponseConverter = new JacksonResponseConverterFunction(objectMapper);
     serverBuilder.annotatedService(new ChangeResource(tilesetPath, stylePath),
         jsonResponseConverter);
-    serverBuilder.annotatedService(new TileResource(tileStoreSupplier), jsonResponseConverter);
+    serverBuilder.annotatedService("/tiles", new VectorTileResource(tileStoreSupplier),
+        jsonResponseConverter);
     serverBuilder.annotatedService(new StyleResource(styleSupplier), jsonResponseConverter);
     serverBuilder.annotatedService(new TilesetResource(tilesetSupplier), jsonResponseConverter);
 
