@@ -28,25 +28,29 @@ import com.linecorp.armeria.server.cors.CorsService;
 import com.linecorp.armeria.server.docs.DocService;
 import com.linecorp.armeria.server.file.FileService;
 import com.linecorp.armeria.server.file.HttpFile;
+import java.nio.ByteBuffer;
 import java.nio.file.Path;
 import java.util.concurrent.Callable;
 import java.util.function.Supplier;
 import org.apache.baremaps.cli.Options;
 import org.apache.baremaps.config.ConfigReader;
+import org.apache.baremaps.maplibre.style.Style;
+import org.apache.baremaps.maplibre.tilejson.TileJSON;
 import org.apache.baremaps.server.*;
-import org.apache.baremaps.tilestore.TileCache;
 import org.apache.baremaps.tilestore.TileStore;
 import org.apache.baremaps.tilestore.mbtiles.MBTilesStore;
+import org.apache.baremaps.tilestore.vector.VectorTileCache;
 import org.apache.baremaps.utils.SqliteUtils;
-import org.apache.baremaps.vectortile.style.Style;
-import org.apache.baremaps.vectortile.tilejson.TileJSON;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import picocli.CommandLine.Command;
 import picocli.CommandLine.Mixin;
 import picocli.CommandLine.Option;
 
-@Command(name = "mbtiles", description = "Start a mbtiles server with caching capabilities.")
+@Command(
+    name = "mbtiles",
+    description = "Start a mbtiles server with caching capabilities.")
+@SuppressWarnings("squid:S106")
 public class MBTiles implements Callable<Integer> {
 
   private static final Logger logger = LoggerFactory.getLogger(MBTiles.class);
@@ -79,50 +83,53 @@ public class MBTiles implements Callable<Integer> {
     var caffeineSpec = CaffeineSpec.parse(cache);
 
     var datasource = SqliteUtils.createDataSource(mbtilesPath, true);
-    var tileStore = new MBTilesStore(datasource);
-    var tileCache = new TileCache(tileStore, caffeineSpec);
-    var tileStoreSupplier = (Supplier<TileStore>) () -> tileCache;
+    try (var tileStore = new MBTilesStore(datasource);
+        var tileCache = new VectorTileCache(tileStore, caffeineSpec)) {
+      var tileStoreSupplier = (Supplier<TileStore<ByteBuffer>>) () -> tileCache;
 
-    var style = objectMapper.readValue(configReader.read(stylePath), Style.class);
-    var styleSupplier = (Supplier<Style>) () -> style;
+      var style = objectMapper.readValue(configReader.read(stylePath), Style.class);
+      var styleSupplier = (Supplier<Style>) () -> style;
 
-    var tileJSON = objectMapper.readValue(configReader.read(tileJSONPath), TileJSON.class);
-    var tileJSONSupplier = (Supplier<TileJSON>) () -> tileJSON;
+      var tileJSON = objectMapper.readValue(configReader.read(tileJSONPath), TileJSON.class);
+      var tileJSONSupplier = (Supplier<TileJSON>) () -> tileJSON;
 
-    var serverBuilder = Server.builder();
-    serverBuilder.http(port);
+      var serverBuilder = Server.builder();
+      serverBuilder.http(port);
 
-    var jsonResponseConverter = new JacksonResponseConverterFunction(objectMapper);
-    serverBuilder.annotatedService(new TileResource(tileStoreSupplier), jsonResponseConverter);
-    serverBuilder.annotatedService(new StyleResource(styleSupplier), jsonResponseConverter);
-    serverBuilder.annotatedService(new TileJSONResource(tileJSONSupplier), jsonResponseConverter);
+      var jsonResponseConverter = new JacksonResponseConverterFunction(objectMapper);
+      serverBuilder.annotatedService("/tiles", new VectorTileResource(tileStoreSupplier),
+          jsonResponseConverter);
+      serverBuilder.annotatedService(new StyleResource(styleSupplier), jsonResponseConverter);
+      serverBuilder.annotatedService(new TileJSONResource(tileJSONSupplier), jsonResponseConverter);
 
-    var index = HttpFile.of(ClassLoader.getSystemClassLoader(), "/static/server.html");
-    serverBuilder.service("/", index.asService());
-    serverBuilder.serviceUnder("/", FileService.of(ClassLoader.getSystemClassLoader(), "/static"));
+      var index = HttpFile.of(ClassLoader.getSystemClassLoader(), "/static/server.html");
+      serverBuilder.service("/", index.asService());
+      serverBuilder.serviceUnder("/",
+          FileService.of(ClassLoader.getSystemClassLoader(), "/static"));
 
-    serverBuilder.decorator(CorsService.builderForAnyOrigin()
-        .allowRequestMethods(HttpMethod.GET, HttpMethod.POST, HttpMethod.PUT, HttpMethod.DELETE,
-            HttpMethod.OPTIONS, HttpMethod.HEAD)
-        .allowRequestHeaders(HttpHeaderNames.ORIGIN, HttpHeaderNames.CONTENT_TYPE,
-            HttpHeaderNames.ACCEPT, HttpHeaderNames.AUTHORIZATION)
-        .allowCredentials()
-        .exposeHeaders(HttpHeaderNames.LOCATION)
-        .newDecorator());
+      serverBuilder.decorator(CorsService.builderForAnyOrigin()
+          .allowRequestMethods(HttpMethod.GET, HttpMethod.POST, HttpMethod.PUT, HttpMethod.DELETE,
+              HttpMethod.OPTIONS, HttpMethod.HEAD)
+          .allowRequestHeaders(HttpHeaderNames.ORIGIN, HttpHeaderNames.CONTENT_TYPE,
+              HttpHeaderNames.ACCEPT, HttpHeaderNames.AUTHORIZATION)
+          .allowCredentials()
+          .exposeHeaders(HttpHeaderNames.LOCATION)
+          .newDecorator());
 
-    serverBuilder.serviceUnder("/docs", new DocService());
+      serverBuilder.serviceUnder("/docs", new DocService());
 
-    serverBuilder.disableServerHeader();
-    serverBuilder.disableDateHeader();
+      serverBuilder.disableServerHeader();
+      serverBuilder.disableDateHeader();
 
-    var server = serverBuilder.build();
+      var server = serverBuilder.build();
 
-    var startFuture = server.start();
-    startFuture.join();
+      var startFuture = server.start();
+      startFuture.join();
 
-    var shutdownFuture = server.closeOnJvmShutdown();
-    shutdownFuture.join();
+      var shutdownFuture = server.closeOnJvmShutdown();
+      shutdownFuture.join();
 
+    }
     return 0;
   }
 }
