@@ -28,29 +28,33 @@ import com.linecorp.armeria.server.cors.CorsService;
 import com.linecorp.armeria.server.docs.DocService;
 import com.linecorp.armeria.server.file.FileService;
 import com.linecorp.armeria.server.file.HttpFile;
+import java.nio.ByteBuffer;
 import java.nio.file.Path;
 import java.util.concurrent.Callable;
 import java.util.function.Supplier;
 import org.apache.baremaps.cli.Options;
 import org.apache.baremaps.config.ConfigReader;
+import org.apache.baremaps.maplibre.style.Style;
+import org.apache.baremaps.maplibre.tilejson.TileJSON;
+import org.apache.baremaps.maplibre.tileset.Tileset;
+import org.apache.baremaps.postgres.utils.PostgresUtils;
 import org.apache.baremaps.server.SearchResource;
 import org.apache.baremaps.server.StyleResource;
 import org.apache.baremaps.server.TileJSONResource;
-import org.apache.baremaps.server.TileResource;
-import org.apache.baremaps.tilestore.TileCache;
+import org.apache.baremaps.server.VectorTileResource;
 import org.apache.baremaps.tilestore.TileStore;
 import org.apache.baremaps.tilestore.postgres.PostgresTileStore;
-import org.apache.baremaps.utils.PostgresUtils;
-import org.apache.baremaps.vectortile.style.Style;
-import org.apache.baremaps.vectortile.tilejson.TileJSON;
-import org.apache.baremaps.vectortile.tileset.Tileset;
+import org.apache.baremaps.tilestore.vector.VectorTileCache;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 import picocli.CommandLine.Command;
 import picocli.CommandLine.Mixin;
 import picocli.CommandLine.Option;
 
-@Command(name = "serve", description = "Start a tile server with caching capabilities.")
+@Command(
+    name = "serve",
+    description = "Start a tile server with caching capabilities.")
+@SuppressWarnings("squid:S106")
 public class Serve implements Callable<Integer> {
 
   private static final Logger logger = LoggerFactory.getLogger(Serve.class);
@@ -90,55 +94,60 @@ public class Serve implements Callable<Integer> {
     var tileset = objectMapper.readValue(configReader.read(tilesetPath), Tileset.class);
     var datasource = PostgresUtils.createDataSourceFromObject(tileset.getDatabase());
 
-    var tileStore = new PostgresTileStore(datasource, tileset);
-    var tileCache = new TileCache(tileStore, caffeineSpec);
-    var tileStoreSupplier = (Supplier<TileStore>) () -> tileCache;
+    try (
+        var tileStore = new PostgresTileStore(datasource, tileset);
+        var tileCache = new VectorTileCache(tileStore, caffeineSpec)) {
 
-    var style = objectMapper.readValue(configReader.read(stylePath), Style.class);
-    var styleSupplier = (Supplier<Style>) () -> style;
+      var tileStoreSupplier = (Supplier<TileStore<ByteBuffer>>) () -> tileCache;
 
-    var tileJSON = objectMapper.readValue(configReader.read(tilesetPath), TileJSON.class);
-    var tileJSONSupplier = (Supplier<TileJSON>) () -> tileJSON;
+      var style = objectMapper.readValue(configReader.read(stylePath), Style.class);
+      var styleSupplier = (Supplier<Style>) () -> style;
 
-    var serverBuilder = Server.builder();
-    serverBuilder.http(port);
+      var tileJSON = objectMapper.readValue(configReader.read(tilesetPath), TileJSON.class);
+      var tileJSONSupplier = (Supplier<TileJSON>) () -> tileJSON;
 
-    var jsonResponseConverter = new JacksonResponseConverterFunction(objectMapper);
-    serverBuilder.annotatedService(new TileResource(tileStoreSupplier), jsonResponseConverter);
-    serverBuilder.annotatedService(new StyleResource(styleSupplier), jsonResponseConverter);
-    serverBuilder.annotatedService(new TileJSONResource(tileJSONSupplier), jsonResponseConverter);
-    serverBuilder.annotatedService(new SearchResource(datasource), jsonResponseConverter);
+      var serverBuilder = Server.builder();
+      serverBuilder.http(port);
 
-    var index = HttpFile.of(ClassLoader.getSystemClassLoader(), "/static/server.html");
-    serverBuilder.service("/", index.asService());
-    serverBuilder.serviceUnder("/", FileService.of(ClassLoader.getSystemClassLoader(), "/static"));
+      var jsonResponseConverter = new JacksonResponseConverterFunction(objectMapper);
+      serverBuilder.annotatedService("/tiles", new VectorTileResource(tileStoreSupplier),
+          jsonResponseConverter);
+      serverBuilder.annotatedService(new StyleResource(styleSupplier), jsonResponseConverter);
+      serverBuilder.annotatedService(new TileJSONResource(tileJSONSupplier), jsonResponseConverter);
+      serverBuilder.annotatedService(new SearchResource(datasource), jsonResponseConverter);
 
-    if (assetsPath != null) {
-      serverBuilder.serviceUnder("/assets", FileService.of(assetsPath));
+      var index = HttpFile.of(ClassLoader.getSystemClassLoader(), "/static/server.html");
+      serverBuilder.service("/", index.asService());
+      serverBuilder.serviceUnder("/",
+          FileService.of(ClassLoader.getSystemClassLoader(), "/static"));
+
+      if (assetsPath != null) {
+        serverBuilder.serviceUnder("/assets", FileService.of(assetsPath));
+      }
+
+      serverBuilder.decorator(CorsService.builderForAnyOrigin()
+          .allowRequestMethods(HttpMethod.GET, HttpMethod.POST, HttpMethod.PUT, HttpMethod.DELETE,
+              HttpMethod.OPTIONS, HttpMethod.HEAD)
+          .allowRequestHeaders(HttpHeaderNames.ORIGIN, HttpHeaderNames.CONTENT_TYPE,
+              HttpHeaderNames.ACCEPT, HttpHeaderNames.AUTHORIZATION)
+          .allowCredentials()
+          .exposeHeaders(HttpHeaderNames.LOCATION)
+          .newDecorator());
+
+      serverBuilder.serviceUnder("/docs", new DocService());
+
+      serverBuilder.disableServerHeader();
+      serverBuilder.disableDateHeader();
+
+      var server = serverBuilder.build();
+
+      var startFuture = server.start();
+      startFuture.join();
+
+      var shutdownFuture = server.closeOnJvmShutdown();
+      shutdownFuture.join();
     }
 
-    serverBuilder.decorator(CorsService.builderForAnyOrigin()
-        .allowRequestMethods(HttpMethod.GET, HttpMethod.POST, HttpMethod.PUT, HttpMethod.DELETE,
-            HttpMethod.OPTIONS, HttpMethod.HEAD)
-        .allowRequestHeaders(HttpHeaderNames.ORIGIN, HttpHeaderNames.CONTENT_TYPE,
-            HttpHeaderNames.ACCEPT, HttpHeaderNames.AUTHORIZATION)
-        .allowCredentials()
-        .exposeHeaders(HttpHeaderNames.LOCATION)
-        .newDecorator());
-
-    serverBuilder.serviceUnder("/docs", new DocService());
-
-    serverBuilder.disableServerHeader();
-    serverBuilder.disableDateHeader();
-
-    var server = serverBuilder.build();
-
-    var startFuture = server.start();
-    startFuture.join();
-
-    var shutdownFuture = server.closeOnJvmShutdown();
-    shutdownFuture.join();
-
     return 0;
   }
 }
