@@ -39,7 +39,7 @@ import org.apache.baremaps.tilestore.TileStoreException;
  * <a href="https://docs.mapbox.com/help/glossary/mbtiles/">MBTiles</a> file format for storing
  * tiles.
  */
-public class MBTilesStore implements TileStore {
+public class MBTilesStore implements TileStore<ByteBuffer> {
 
   public static final String CREATE_TABLE_METADATA =
       "CREATE TABLE IF NOT EXISTS metadata (name TEXT, value TEXT, PRIMARY KEY (name))";
@@ -119,21 +119,19 @@ public class MBTilesStore implements TileStore {
    * {@inheritDoc}
    */
   @Override
-  public void write(List<TileEntry> tileEntries) throws TileStoreException {
-    try (Connection connection = dataSource.getConnection()) {
-      // connection.setAutoCommit(false);
-      try (PreparedStatement statement = connection.prepareStatement(INSERT_TILE)) {
-        for (TileEntry tileEntry : tileEntries) {
-          TileCoord tileCoord = tileEntry.getTileCoord();
-          ByteBuffer byteBuffer = tileEntry.getByteBuffer();
-          statement.setInt(1, tileCoord.z());
-          statement.setInt(2, tileCoord.x());
-          statement.setInt(3, reverseY(tileCoord.y(), tileCoord.z()));
-          statement.setBytes(4, byteBuffer.array());
-          statement.execute();
-        }
+  public void write(List<TileEntry<ByteBuffer>> tileEntries) throws TileStoreException {
+    try (
+        Connection connection = dataSource.getConnection();
+        PreparedStatement statement = connection.prepareStatement(INSERT_TILE)) {
+      for (TileEntry<ByteBuffer> tileEntry : tileEntries) {
+        TileCoord tileCoord = tileEntry.getTileCoord();
+        ByteBuffer byteBuffer = tileEntry.getTileValue();
+        statement.setInt(1, tileCoord.z());
+        statement.setInt(2, tileCoord.x());
+        statement.setInt(3, reverseY(tileCoord.y(), tileCoord.z()));
+        statement.setBytes(4, byteBuffer.array());
+        statement.execute();
       }
-      // connection.commit();
     } catch (SQLException e) {
       throw new TileStoreException(e);
     }
