@@ -26,10 +26,10 @@ import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import java.util.zip.GZIPOutputStream;
 import javax.sql.DataSource;
+import org.apache.baremaps.maplibre.tileset.Tileset;
 import org.apache.baremaps.tilestore.TileCoord;
 import org.apache.baremaps.tilestore.TileStore;
 import org.apache.baremaps.tilestore.TileStoreException;
-import org.apache.baremaps.vectortile.tileset.Tileset;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -38,7 +38,7 @@ import org.slf4j.LoggerFactory;
  * This {@code TileStore} combines the input queries, identifies common table expressions (CTE), and
  * generates a single optimized sql that hits the database.
  */
-public class PostgresTileStore implements TileStore {
+public class PostgresTileStore implements TileStore<ByteBuffer> {
 
   private static final Logger logger = LoggerFactory.getLogger(PostgresTileStore.class);
 
@@ -60,7 +60,7 @@ public class PostgresTileStore implements TileStore {
   /**
    * A cache of queries.
    */
-  private Map<Integer, Query> cache = new ConcurrentHashMap<>();
+  private final Map<Integer, Query> cache = new ConcurrentHashMap<>();
 
   /**
    * A record that holds the sql of a prepared statement and the number of parameters.
@@ -125,6 +125,7 @@ public class PostgresTileStore implements TileStore {
    * @param zoom the zoom level
    * @return
    */
+  @SuppressWarnings("squid:S3776")
   protected static Query prepareQuery(Tileset tileset, int zoom) {
     // Initialize a builder for the tile sql
     var tileSql = new StringBuilder();
@@ -164,8 +165,8 @@ public class PostgresTileStore implements TileStore {
               .replace("$zoom", String.valueOf(zoom));
           var querySqlWithParams = String.format(
               "SELECT ST_AsMVTGeom(t.geom, ST_TileEnvelope(?, ?, ?)) AS geom, t.tags - 'id' AS tags, t.id AS id "
-                  +
-                  "FROM (%s) AS t WHERE t.geom IS NOT NULL AND t.geom && ST_TileEnvelope(?, ?, ?, margin => (64.0/4096))",
+                  + "FROM (%s) AS t WHERE t.geom IS NOT NULL "
+                  + "AND t.geom && ST_TileEnvelope(?, ?, ?, margin => (64.0/4096))",
               querySql);
           layerSql.append(querySqlWithParams);
 
