@@ -25,7 +25,7 @@ import com.fasterxml.jackson.annotation.JsonSubTypes.Type;
 import com.fasterxml.jackson.annotation.JsonTypeInfo;
 import com.fasterxml.jackson.annotation.JsonTypeInfo.Id;
 import com.fasterxml.jackson.databind.annotation.JsonSerialize;
-import org.apache.baremaps.workflow.tasks.*;
+import org.apache.baremaps.tasks.*;
 
 /**
  * A task is a unit of work executed in a step of a workflow.
@@ -47,6 +47,7 @@ import org.apache.baremaps.workflow.tasks.*;
     @Type(value = ImportDaylightFeatures.class, name = "ImportDaylightFeatures"),
     @Type(value = ImportDaylightTranslations.class, name = "ImportDaylightTranslations"),
     @Type(value = ImportGeoPackage.class, name = "ImportGeoPackage"),
+    @Type(value = ImportGeoParquet.class, name = "ImportGeoParquet"),
     @Type(value = ImportOsmOsc.class, name = "ImportOsmOsc"),
     @Type(value = ImportOsmPbf.class, name = "ImportOsmPbf"),
     @Type(value = ImportShapefile.class, name = "ImportShapefile"),
@@ -61,6 +62,7 @@ public interface Task {
    * @param context the context of the workflow
    * @throws Exception if an error occurs during the execution of the task
    */
+  @SuppressWarnings("java:S112")
   void execute(WorkflowContext context) throws Exception;
 
 }
