@@ -26,12 +26,11 @@ import java.util.List;
 import java.util.Map;
 import java.util.concurrent.ConcurrentHashMap;
 import javax.sql.DataSource;
-import org.apache.baremaps.database.collection.*;
-import org.apache.baremaps.database.memory.MemoryMappedDirectory;
-import org.apache.baremaps.database.type.*;
-import org.apache.baremaps.database.type.geometry.LonLatDataType;
+import org.apache.baremaps.data.collection.*;
+import org.apache.baremaps.data.memory.MemoryMappedDirectory;
+import org.apache.baremaps.data.type.*;
+import org.apache.baremaps.postgres.utils.PostgresUtils;
 import org.apache.baremaps.utils.FileUtils;
-import org.apache.baremaps.utils.PostgresUtils;
 import org.locationtech.jts.geom.Coordinate;
 
 /**
@@ -64,15 +63,15 @@ public class WorkflowContext {
     return dataSources.computeIfAbsent(database, PostgresUtils::createDataSourceFromObject);
   }
 
-  public DataMap<Long, Coordinate> getCoordinateMap() throws IOException {
-    return getMemoryAlignedDataMap("coordinates", new LonLatDataType());
+  public Map<Long, Coordinate> getCoordinateMap() throws IOException {
+    return DataConversions.asMap(getMonotonicPairedDataMap("coordinates", new LonLatDataType()));
   }
 
-  public DataMap<Long, List<Long>> getReferenceMap() throws IOException {
-    return getMonotonicDataMap("references", new LongListDataType());
+  public Map<Long, List<Long>> getReferenceMap() throws IOException {
+    return DataConversions.asMap(getMonotonicDataMap("references", new LongListDataType()));
   }
 
-  public <T> DataMap<Long, T> getMemoryAlignedDataMap(String name, FixedSizeDataType<T> dataType)
+  private <T> DataMap<Long, T> getMemoryAlignedDataMap(String name, FixedSizeDataType<T> dataType)
       throws IOException {
     var coordinateDir = Files.createDirectories(cacheDir.resolve(name));
     return new MemoryAlignedDataMap<>(
@@ -80,7 +79,7 @@ public class WorkflowContext {
         new MemoryMappedDirectory(coordinateDir));
   }
 
-  public <T> DataMap<Long, T> getMonotonicDataMap(String name, DataType<T> dataType)
+  private <T> DataMap<Long, T> getMonotonicDataMap(String name, DataType<T> dataType)
       throws IOException {
     var mapDir = Files.createDirectories(cacheDir.resolve(name));
     var keysDir = Files.createDirectories(mapDir.resolve("keys"));
@@ -89,11 +88,21 @@ public class WorkflowContext {
         new MemoryAlignedDataList<>(
             new PairDataType<>(new LongDataType(), new LongDataType()),
             new MemoryMappedDirectory(keysDir)),
-        new AppendOnlyBuffer<>(
+        new AppendOnlyLog<>(
             dataType,
             new MemoryMappedDirectory(valuesDir)));
   }
 
+  private DataMap<Long, Coordinate> getMonotonicPairedDataMap(String name,
+      DataType<Coordinate> dataType)
+      throws IOException {
+    var mapDir = Files.createDirectories(cacheDir.resolve(name));
+    return new MonotonicPairedDataMap<>(
+        new MemoryAlignedDataList<>(
+            new PairDataType<>(new LongDataType(), new LonLatDataType()),
+            new MemoryMappedDirectory(Files.createDirectories(mapDir))));
+  }
+
   public void cleanCache() throws IOException {
     FileUtils.deleteRecursively(cacheDir);
   }
