@@ -21,22 +21,23 @@ package org.apache.baremaps.workflow;
 
 import java.nio.file.Paths;
 import java.util.List;
+import org.apache.baremaps.tasks.*;
+import org.apache.baremaps.tasks.DecompressFile.Compression;
 import org.apache.baremaps.testing.PostgresContainerTest;
-import org.apache.baremaps.workflow.tasks.*;
-import org.apache.baremaps.workflow.tasks.DecompressFile.Compression;
 import org.junit.jupiter.api.Disabled;
 import org.junit.jupiter.api.Test;
 
+@SuppressWarnings("squid:S2699")
 class WorkflowTest extends PostgresContainerTest {
 
   @Test
-  @Disabled
+  @Disabled("requires internet access")
   void naturalearthGeoPackage() {
     var workflow = new Workflow(List.of(new Step("fetch-geopackage", List.of(), List.of(
         new DownloadUrl("https://naciscdn.org/naturalearth/packages/natural_earth_vector.gpkg.zip",
             Paths.get("natural_earth_vector.gpkg.zip"), false),
         new DecompressFile(Paths.get("natural_earth_vector.gpkg.zip"),
-            Paths.get("natural_earth_vector"), Compression.zip),
+            Paths.get("natural_earth_vector"), Compression.ZIP),
         new ImportGeoPackage(Paths.get("natural_earth_vector/packages/natural_earth_vector.gpkg"),
             4326, jdbcUrl(),
             3857)))));
@@ -44,14 +45,14 @@ class WorkflowTest extends PostgresContainerTest {
   }
 
   @Test
-  @Disabled
+  @Disabled("requires internet access")
   void coastlineShapefile() {
     var workflow = new Workflow(List.of(new Step("fetch-geopackage", List.of(),
         List.of(
             new DownloadUrl("https://osmdata.openstreetmap.de/download/coastlines-split-4326.zip",
                 Paths.get("coastlines-split-4326.zip"), false),
             new DecompressFile(Paths.get("coastlines-split-4326.zip"),
-                Paths.get("coastlines-split-4326"), Compression.zip),
+                Paths.get("coastlines-split-4326"), Compression.ZIP),
             new ImportShapefile(Paths.get("coastlines-split-4326/coastlines-split-4326/lines.shp"),
                 4326, jdbcUrl(),
                 3857)))));
@@ -59,7 +60,7 @@ class WorkflowTest extends PostgresContainerTest {
   }
 
   @Test
-  @Disabled
+  @Disabled("requires internet access")
   void simplifiedWaterPolygonsShapefile() {
     var workflow = new Workflow(List.of(new Step("simplified-water-polygons", List.of(), List.of(
         /*
@@ -77,7 +78,7 @@ class WorkflowTest extends PostgresContainerTest {
   }
 
   @Test
-  @Disabled
+  @Disabled("requires internet access")
   void workflow() {
     var workflow = new Workflow(List.of(new Step("fetch-geopackage", List.of(), List.of(
         new DownloadUrl("https://naciscdn.org/naturalearth/packages/natural_earth_vector.gpkg.zip",
@@ -87,7 +88,7 @@ class WorkflowTest extends PostgresContainerTest {
   }
 
   @Test
-  @Disabled
+  @Disabled("requires internet access")
   void execute() {
     var workflow = new Workflow(List.of(
         new Step("fetch-geopackage", List.of(),
@@ -109,7 +110,7 @@ class WorkflowTest extends PostgresContainerTest {
         new Step("unzip-shapefile", List.of("fetch-shapefile"),
             List.of(
                 new DecompressFile(Paths.get("downloads/simplified-water-polygons-split-3857.zip"),
-                    Paths.get("archives"), Compression.zip))),
+                    Paths.get("archives"), Compression.ZIP))),
         new Step("fetch-projection", List.of("unzip-shapefile"),
             List.of(new DownloadUrl("https://spatialreference.org/ref/sr-org/epsg3857/prj/",
                 Paths.get(
